OC.L10N.register(
    "settings",
    {
    "Migration in progress. Please wait until the migration is finished" : "המרה בביצוע. יש להמתין עד סיום ההמרה",
    "Migration started …" : "המרה החלה...",
    "Saved" : "נשמר",
    "Not saved" : "לא נשמר",
    "Sending…" : "בשליחה…",
    "Email sent" : "הודעת הדואר האלקטרוני נשלחה",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "אירעה שגיאה. יש להעלות תעודת ASCII-encoded PEM.",
    "Valid until {date}" : "בתוקף עד ל- {date}",
    "Delete" : "מחיקה",
    "Local" : "מקומ",
    "Private" : "פרטי",
    "Only visible to local users" : "גלוי למשתמשים מקומיים בלבד",
    "Only visible to you" : "גלוי רק לך",
    "Contacts" : "אנשי קשר",
    "Visible to local users and to trusted servers" : "גלוי למשתמשים מקומיים ולשרתים מהימנים",
    "Public" : "ציבורי",
    "Will be synced to a global and public address book" : "יסונכרן לספר כתובות גלובלי וציבורי",
    "Verify" : "אימות",
    "Verifying …" : "מתבצע אימות…",
    "Unable to change password" : "לא ניתן לשנות את הססמה",
    "Very weak password" : "סיסמא מאוד חלשה",
    "Weak password" : "סיסמא חלשה",
    "So-so password" : "סיסמא ככה-ככה",
    "Good password" : "סיסמא טובה",
    "Strong password" : "סיסמא חזקה",
    "Select a profile picture" : "יש לבחור תמונת פרופיל",
    "Week starts on {fdow}" : "השבוע מתחיל ב{fdow}",
    "Groups" : "קבוצות",
    "Group list is empty" : "רשימת הקבוצות ריקה",
    "Unable to retrieve the group list" : "לא ניתן לקבל את רשימת הקבוצות",
    "{actor} added you to group {group}" : "נוספת לקבוצה {group} על ידי {actor}",
    "You added {user} to group {group}" : "הוספת את {user} לקבוצה {group}",
    "{actor} added {user} to group {group}" : "ההוספה של {user} לקבוצה {group} נעשתה על ידי {actor}",
    "An administrator added you to group {group}" : "נוספת לקבוצה {group} על ידי מנהל",
    "{actor} changed your password" : "הססמה שלך הוחלפה על ידי {actor}",
    "You changed your password" : "שינית את הססמה שלך",
    "Your password was reset by an administrator" : "הססמה שלך אופסה על ידי מנהל",
    "{actor} changed your email address" : "כתובת הדוא״ל שלך נערכה על ידי {actor}",
    "You changed your email address" : "שינית את כתובת הדוא״ל שלך",
    "Your email address was changed by an administrator" : "כתובת הדוא״ל שלך נערכה על ידי המנהל",
    "Security" : "אבטחה",
    "You successfully logged in using two-factor authentication (%1$s)" : "נכנסת בהצלחה באמצעות אימות דו־שלבי (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "ניסיון כניסה עם אימות דו־שלבי נכשל (%1$s)",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "ה<strong>סמסה</strong> או <strong>כתוב הדוא״ל שלך</strong> השתנו",
    "Couldn't remove app." : "לא ניתן להסיר את היישום.",
    "Couldn't update app." : "לא ניתן לעדכן את היישום.",
    "Wrong password" : "ססמה שגויה",
    "No user supplied" : "לא סופק שם משתמש",
    "Authentication error" : "שגיאת אימות",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "נא לספק ססמת שחזור של מנהלים, אחרת, כל נתוני המשתמשים ילכו לאיבוד.",
    "Wrong admin recovery password. Please check the password and try again." : "סיסמת המנהל לשחזור שגוייה. יש לבדוק את הסיסמא ולנסות שוב.",
    "Backend doesn't support password change, but the user's encryption key was updated." : "המנגנון אינו תומך בשינוי ססמה אך מפתח ההצפנה של המשתמש עודכן.",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "התקנה ועדכון היישום דרך חנות היישומים או ענן שיתוף מאוגד",
    "Federated Cloud Sharing" : "ענן שיתוף מאוגד",
    "Invalid SMTP password." : "ססמת ה־SMTP שגויה.",
    "Email setting test" : "בדיקת הגדרת דוא״ל",
    "Well done, %s!" : "עבודה יפה, %s!",
    "If you received this email, the email configuration seems to be correct." : "אם קיבלת את הדוא״ל הזה, כנראה שתצורת הדוא״ל נכונה.",
    "Email could not be sent. Check your mail server log" : "לא ניתן לשלוח דוא״ל. נא לבדוק את רישומי שרת הדוא״ל שלך.",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "בעיה אירעה בשליחת הדואר האלקטרוני. יש לשנות את ההגדרות שלך. (שגיאה: %s)",
    "You need to set your user email before being able to send test emails." : "יש להגדיר כתובת דואר אלקטרוני לפני שניתן יהיה לשלוח דואר אלקטרוני לבדיקה.",
    "Invalid mail address" : "כתובת דואר אלקטרוני לא חוקית",
    "Settings saved" : "הגדרות נשמרו",
    "Unable to change full name" : "לא ניתן לשנות שם מלא",
    "Unable to change email address" : "לא ניתן לשנות את כתובת הדוא״ל",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "כדי לאמת את חשבון הטוויטר שלך, עליך לפרסם את הציוץ הבא בטוויטר (נא לוודא שהוא יפורסם ללא ירידות שורה):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "כדי לאמת את האר של, עליך לאחסן את התוכן הבא בשורש האתר שלך תחת ‚‎.well-known/CloudIdVerificationCode.txt’ (עליך לוודא שכל הטקסט הזה מופיע בשורה אחת):",
    "%1$s changed your password on %2$s." : "ססמת ב‏־%2$s הוחלפה על ידי %1$s.",
    "Your password on %s was changed." : "הססמה שלך ב־%s הוחלפה.",
    "Your password on %s was reset by an administrator." : "ססמתך ב־%s אופסה על ידי נציגות מההנהלה.",
    "Password for %1$s changed on %2$s" : "הססמה עבור %1$s הוחלפה ב־%2$s",
    "Password changed for %s" : "הוחלפה הססמה של %s",
    "If you did not request this, please contact an administrator." : "אם לא ביקשת זאת, נא ליצור קשר עם מנהל המערכת.",
    "Your email address on %s was changed." : "כתובת הדוא״ל שלך ב־%s הוחלפה",
    "Your email address on %s was changed by an administrator." : "כתובת הדוא״ל שלך ב־%s הוחלפה על ידי נציגות ההנהלה.",
    "Email address for %1$s changed on %2$s" : "כתובת הדוא״ל עבור %1$s הוחלפה ב־%2$s",
    "Email address changed for %s" : "כתובת הדוא״ל של %s הוחלפה",
    "The new email address is %s" : "כתובת הדוא״ל החדשה היא %s",
    "Your %s account was created" : "חשבון %s שלך נוצר",
    "Welcome aboard" : "ברוך בואך",
    "Welcome aboard %s" : "ברוך בואך %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "ברוך בואך לחשבונך ב־%s, יש לך את האפשרות להוסיף, להגן ולשתף את הנתונים שלך.",
    "Your username is: %s" : "שם המשתמש שלך הוא: %s",
    "Set your password" : "הגדרת הססמה שלך",
    "Go to %s" : "מעבר אל %s",
    "Install Client" : "התקנת לקו",
    "Unlimited" : "ללא הגבלה",
    "Limit to groups" : "הגבלה לקבוצות",
    "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "היישומונים הרשמיים מפותחים על ידי ובתוך הקהילה. הם מציעים תכונות ליבה מסוימות והן מוכנות לשימוש יומיומי.",
    "Official" : "רישמי",
    "Remove" : "הסרה",
    "Disable" : "ניטרול",
    "All" : "הכל",
    "No results" : "אין תוצאות",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "ליישומון זה לא מוקצית גרסת Nextcloud מזערית. מצב כזה עשוי להוביל לשגיאה בעתיד.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "ליישומון זה לא מוקצית גרסת Nextcloud מרבית. מצב כזה עשוי להוביל לשגיאה בעתיד.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "לא ניתן להתקין את יישום זה כיוון שייחסי התלות הבאים לא התקיימו:",
    "View in store" : "הצגה באחסון",
    "Visit website" : "ביקור באתר האינטרנט",
    "Report a bug" : "דיווח על באג",
    "User documentation" : "תיעוד משתמש",
    "Admin documentation" : "תיעוד מנהל",
    "Developer documentation" : "תיעוד מפתח",
    "Update to {update}" : "עדכון ל־{version}",
    "Results from other categories" : "תוצאות מקטגוריות אחרות",
    "No apps found for your version" : "לא נמצאו יישומים לגרסה שלך",
    "Disable all" : "להשבית הכול",
    "Enable all" : "הפעלת הכול",
    "Download and enable" : "להוריד ולהפעיל",
    "Enable" : "הפעלה",
    "Enable untested app" : "לאפשר יישומון שלא נבדק",
    "The app will be downloaded from the app store" : "היישום ירד מחנות היישומים",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "היישומון הזה לא מסומן כנתמך בגרסת ה־Nextcloud. עדיין יתאפשר לך להמשיך ולהתקין את היישומון. נא לשים לב שיכול להיות שהיישומון לא יעבוד כצפוי.",
    "Allow filesystem access" : "לאפשר גישה למערכת הקבצים",
    "Revoke" : "שלילה",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome עבור Android",
    "Sync client - {os}" : "לקוח סנכרון - {os}",
    "This session" : "הפעלה זו",
    "Device" : "התקן",
    "Last activity" : "פעילות אחרונה",
    "Devices & sessions" : "התקנים והפעלות",
    "Web, desktop and mobile clients currently logged in to your account." : "לקוחות שמחוברים כעת לחשבון שלך דרך דפדפן, שולחן עבודה והתקנים ניידים.",
    "Error while creating device token" : "שגיאה בזמן יצירת מחרוזת התקן",
    "Error while deleting the token" : "שגיאה בזמן מחיקת המחרוזת",
    "App name" : "שם יישום",
    "Create new app password" : "יצירת סיסמת יישום חדשה",
    "Use the credentials below to configure your app or device." : "יש להשתמש בפרטי הזיהוי שלהלן כדי להגדיר את היישומון או ההתקן שלך.",
    "For security reasons this password will only be shown once." : "מטעמי אבטחה הססמה תופיע פעם אחת בלבד.",
    "Username" : "שם משתמש",
    "Password" : "סיסמא",
    "Done" : "הסתיים",
    "Copied!" : "הועתק!",
    "Copy" : "העתקה",
    "You do not have permissions to see the details of this user" : "אין לך הרשאות לצפות בפירוט על המשתמש",
    "The backend does not support changing the display name" : "המנגנון שלך לא תומך בשינוי שם התצוגה",
    "New password" : "סיסמא חדשה",
    "Select user quota" : "בחירת מכסת משתמש",
    "No language set" : "לא הוגדרה שפה",
    "Never" : "מעולם לא",
    "Delete user" : "מחיקת משתמש",
    "Disable user" : "השבתת משתמש",
    "Enable user" : "הפעלת משתמש",
    "Resend welcome email" : "שליחת הודעת קבלת פנים בדוא״ל מחדש",
    "{size} used" : "{size} בשימוש",
    "Welcome mail sent!" : "נשלחה הודעת קבלת פנים בדוא״ל!",
    "Display name" : "שם תצוגה",
    "Email" : "דואר אלקטרוני",
    "Group admin for" : "מנהל הקבוצה",
    "Quota" : "מכסה",
    "Language" : "שפה",
    "Storage location" : "מיקום אחסון",
    "User backend" : "מנגנון משתמש",
    "Last login" : "כניסה אחרונה",
    "Default language" : "שפת בררת מחדל",
    "Add a new user" : "הוספת משתמש חדש",
    "No users in here" : "אין כאן משתמשים",
    "Default quota" : "מכסת בררת מחדל",
    "Common languages" : "שפות נפוצות",
    "All languages" : "כל השפות",
    "Your apps" : "היישומונים שלך",
    "Active apps" : "יישומונים פעילים",
    "Disabled apps" : "יישומונים מושבתים",
    "Updates" : "עדכונים",
    "App bundles" : "מאגדי יישומונים",
    "{license}-licensed" : "ברישיון {license}",
    "New user" : "משתמש חדש",
    "Default quota:" : "מכסת בררת מחדל:",
    "Select default quota" : "בחירת מכסת בררת מחדל",
    "Show Languages" : "הצגת שפות",
    "Show last login" : "הצגת כניסה אחרונה",
    "Show user backend" : "הצגת צד אחורי למשתמש",
    "Show storage path" : "הצגת נתיב אחסון",
    "Remove group" : "הסרת קבוצה",
    "Admins" : "מנהלים",
    "Disabled users" : "משתמשים מושבתים",
    "Everyone" : "כולם",
    "Add group" : "הוספת קבוצה",
    "You are about to remove the group {group}. The users will NOT be deleted." : "פעולה זו תסיר את הקבוצה {group}. המשתמשים ﬥﬡ יימחקו.",
    "Please confirm the group removal " : "נא לאשר את הסרת הקבוצה",
    "An error occured during the request. Unable to proceed." : "אירעה שגיאה במהלך הבקשה. לא ניתן להמשיך.",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "היישומון הופעל אך יש לעדכן אותו. ההפניה לעמוד העדכון תחל בעוד 5 שניות.",
    "App update" : "עדכון יישומן",
    "Error: This app can not be enabled because it makes the server unstable" : "שגיאה: לא ניתן להפעיל יישומון זה כיוון שהוא מערער את יציבות השרת.",
    "SSL Root Certificates" : "אישורי אבטחת SSL לנתיב יסוד",
    "Common Name" : "שם משותף",
    "Valid until" : "בתוקף עד",
    "Issued By" : "הוצא על ידי",
    "Valid until %s" : "בתוקף עד %s",
    "Import root certificate" : "יבוא אישור אבטחה לנתיב יסוד",
    "Administrator documentation" : "תיעוד מנהל",
    "Documentation" : "תיעוד",
    "Forum" : "פורום",
    "None" : "כלום",
    "Login" : "התחברות",
    "Plain" : "רגיל",
    "NT LAN Manager" : "מנהל רשת NT",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "שרת דואר אלקטרוני",
    "Open documentation" : "תיעוד פתוח",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "חשוב להגדיר את השרת הזה כדי שיתאפשר לשלוח דרכו הודעות דוא״ל, למשל כדי לאפס ססמה ולשלוח התרעות.",
    "Send mode" : "מצב שליחה",
    "Encryption" : "הצפנה",
    "From address" : "מכתובת",
    "mail" : "mail",
    "Authentication method" : "שיטת אימות",
    "Authentication required" : "נדרש אימות",
    "Server address" : "כתובת שרת",
    "Port" : "שער",
    "Credentials" : "פרטי גישה",
    "SMTP Username" : "שם משתמש SMTP ",
    "SMTP Password" : "סיסמת SMTP",
    "Test email settings" : "בדיקת הגדרות דואר אלקטרוני",
    "Send email" : "שליחת דואר אלקטרוני",
    "Security & setup warnings" : "הזהרות אבטחה והתקנה",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "למטרות אבטחה וביצועים מיטביים עבור המערכת שלך חשוב שהכול יוגדר כראוי. כדי לסייע לך בכך אנו עורכים בדיקות אוטומטיות. נא לעיין בתיעוד המקושר לקבלת מידע נוסף.",
    "All checks passed." : "כל הבדיקות עברו",
    "There are some errors regarding your setup." : "ישנן מגוון שגיאות על ההגדרות שלך.",
    "There are some warnings regarding your setup." : "ישנן מגוון אזהרות על ההגדרות שלך.",
    "Checking for system and security issues." : "נבדקות תקלות מערכת ואבטחה.",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "בדיקת האבטחה של ה־Nextcloud שלך באמצעות <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">סריקת האבטחה שלנו ↖️</a>.",
    "Version" : "גרסה",
    "Two-Factor Authentication" : "אימות דו־שלבי",
    "Server-side encryption" : "הצפנת צד שרת",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "הצפנה בצד השרת מאפשרת להצפין קבצים שנשלחים לשרת. לתכונה זו יש מגבלות כגון ירידה בביצועים, מומלץ להפעיל רק אם יש צורך.",
    "Enable server-side encryption" : "הפעלת הצפנה בצד שרת",
    "Please read carefully before activating server-side encryption: " : "יש לקרוא בתשומת לב רבה לפני שמפעילים הצפנת צד שרת:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "ברגע שהצפנה מופעלת, כל הקבצים שיועלו לשרת מרגע זה יהיו מוצפנים בשרת. ניתן יהיה לנטרל את ההצפנה בעתיד רק אם מודול ההצפנה תומך בפונקציה זו, וכל התנאים המוקדמים (דהיינו הגדרת מפתח השחזור) מתקיימים.",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "הצפנה לבד אינה מספיקה לאבטחה איכותית למערכת. נא לעיין בתיעוד לקבלת פרטים נוספים על אופן הפעולה של יישומון ההצפנה ודרכי היישום הנתמכות.",
    "Be aware that encryption always increases the file size." : "תשומת לב לכך שהצפנה בהכרח מגדילה את גודל הקובץ.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "תמיד טוב ליצור גיבוי קבוע למידע , במקרה של הצפנה יש לוודא שגם מפתחות ההצפנה מגובים עם המידע שלך.",
    "This is the final warning: Do you really want to enable encryption?" : "זו הזהרה אחרונה: האם באמת ברצונך להפעיל הצפנה?",
    "Enable encryption" : "אפשר הצפנה",
    "No encryption module loaded, please enable an encryption module in the app menu." : "לא נמצא מודול הצפנה, יש לאפשר מודול הצפנה בתפריט היישומים.",
    "Select default encryption module:" : "יש לבחור מודול הצפנת ברירת מחדל:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "יש להמיר את מפתחות ההצפנה שלך בממערכת ההצפנה הישנה (ownCloud <= 8.0) למערכת החדשה. יש לאפשר את \"מודול הצפנה ברירת מחדש\" ולהריץ 'occ encryption:migrate'",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "יש להמיר את מפתחות ההצפנה שלך בממערכת ההצפנה הישנה (ownCloud <= 8.0) למערכת החדשה.",
    "Start migration" : "התחלת המרה",
    "Background jobs" : "משימות רקע",
    "Last job ran %s." : "המשימה האחרונה רצה למשך %s.",
    "Last job execution ran %s. Something seems wrong." : "פעילות ההרצה האחרונה נמשכה %s. משהו שם נראה לא תקין.",
    "Background job didn’t run yet!" : "משימת הרקע לא רצה עדיין!",
    "For optimal performance it's important to configure background jobs correctly. For bigger instances 'Cron' is the recommended setting. Please see the documentation for more information." : "לביצועים מיטביים חשוב להגדיר משימות רקע כראוי. למערכות גדולות יותר מוטב להשתמש ב־‚Cron’. נא לעיין בתיעוד לקבל מידע נוסף.",
    "Execute one task with each page loaded" : "יש להפעיל משימה אחת עם כל עמוד שנטען",
    "The cron.php needs to be executed by the system user \"%s\"." : "יש להפעיל את cron.php בתור משתמש המערכת „%s”.",
    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "כדי להריץ זאת יש צורך בהרחבת POSIX ל־PHP. נא לעיין ב{linkstart}תיעוד של PHP{linkend} לפרטים נוספים.",
    "Sharing" : "שיתוף",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "כמנהל יש לך אפשרות לכוונן את התנהגות השיתוף. נא לעיין בתיעוד לפרטים נוספים.",
    "Allow apps to use the Share API" : "לאפשר ליישום להשתמש ב־API השיתוף",
    "Allow users to share via link" : "אפשר למשתמשים לשתף באמצעות קישור",
    "Allow public uploads" : "אפשר העלאות ציבוריות",
    "Always ask for a password" : "תמיד לבקש ססמה",
    "Enforce password protection" : "חייב הגנת סיסמא",
    "Set default expiration date" : "הגדרת תאריך תפוגה ברירת מחדל",
    "Expire after " : "פג אחרי",
    "days" : "ימים",
    "Enforce expiration date" : "חייב תאריך תפוגה",
    "Allow resharing" : "לאפשר שיתוף מחדש",
    "Allow sharing with groups" : "מאפשר שיתוף עם קבוצות",
    "Restrict users to only share with users in their groups" : "הגבלת משתמשים לשתף רק עם משתמשים בקבוצה שלהם",
    "Exclude groups from sharing" : "מניעת קבוצות משיתוף",
    "These groups will still be able to receive shares, but not to initiate them." : "קבוצות אלו עדיין יוכלו לקבל שיתופים, אך לא לשתף בעצמם.",
    "Allow username autocompletion in share dialog. If this is disabled the full username or email address needs to be entered." : "לאפשר השלמת שם משתמש אוטומטית בתיבת השיתוף. אם האפשרות הזו מושבתת יש להקליד את שם המשתמש או את כתובת הדוא״ל במלואם.",
    "Show disclaimer text on the public link upload page. (Only shown when the file list is hidden.)" : "הצגת טקסט ויתור בעמוד העלאת קישור ציבורי. (מופיע רק כאשר רשימת הקבצים מוסתרת.)",
    "This text will be shown on the public link upload page when the file list is hidden." : "טקסט זה יופיע בקישור עמוד ההעלאה של הקישור הציבורי כאשר רשימת הקבצים מוסתרת.",
    "Default share permissions" : "הרשאות שיתוף כבררת מחדל",
    "Personal" : "אישי",
    "Administration" : "ניהול",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "בפיתוח על ידי {communityopen}קהילת Nextcloud{linkclose}, {githubopen}קוד המקור{linkclose} זמין ברישיון {licenseopen}AGPL{linkclose}.",
    "Like our Facebook page" : "לייק לעמוד הפייסבוק שלנו",
    "Follow us on Twitter" : "לעקוב אחרינו בטוויטר",
    "Check out our blog" : "לעיין בבלוג שלנו",
    "Subscribe to our newsletter" : "הרשמה לרשימת הדיוור שלנו",
    "Profile picture" : "תמונת פרופיל",
    "Upload new" : "העלאת חדש",
    "Select from Files" : "בחירה מתוך קבצים",
    "Remove image" : "הסרת תמונה",
    "png or jpg, max. 20 MB" : "png או jpg, מקסימום 20 מגה-בייט",
    "Picture provided by original account" : "תמונה סופקה על ידי חשבון מקור",
    "Cancel" : "ביטול",
    "Choose as profile picture" : "יש לבחור כתמונת פרופיל",
    "Details" : "פרטים",
    "You are a member of the following groups:" : "הקבוצות הבאות כוללות אותך:",
    "You are using <strong>%s</strong>" : "הניצולת שלך היא <strong>%s</strong>",
    "Full name" : "שם מלא",
    "No display name set" : "לא נקבע שם תצוגה",
    "Your email address" : "כתובת הדואר האלקטרוני שלך",
    "No email address set" : "לא נקבעה כתובת דואר אלקטרוני",
    "For password reset and notifications" : "לאיפוס ססמה והתרעות",
    "Phone number" : "מספר טלפון",
    "Your phone number" : "מספר הטלפון שלך",
    "Address" : "כתובת",
    "Your postal address" : "כתובת הדואר שלך",
    "Website" : "אתר",
    "It can take up to 24 hours before the account is displayed as verified." : "יתכן שיעברו עד 24 שעות בטרם הצגת החשבון כמאומת.",
    "Link https://…" : "קישור https://…‎",
    "Twitter" : "טוויטר",
    "Twitter handle @…" : "כינוי בטוויטר @…",
    "Help translate" : "עזרה בתרגום",
    "Locale" : "הגדרות אזוריות",
    "Current password" : "סיסמא נוכחית",
    "Change password" : "שינוי סיסמא",
    "Disconnect" : "ניתוק",
    "Press ⌘-C to copy." : "‎⌘-C להעתקה.",
    "Press Ctrl-C to copy." : "Ctrl-C להעתקה.",
    "Afrikaans (Namibia)" : "אפריקאנס (נמיביה)",
    "Afrikaans (South Africa)" : "אפריקאנס (דרום אפריקה)",
    "Afrikaans" : "אפריקאנס",
    "Albanian (Albania)" : "אלבנית (אלבניה)",
    "Albanian" : "אלבנית",
    "Amharic (Ethiopia)" : "אמהרית (אתיופיה)",
    "Amharic" : "אמהרית",
    "Arabic (Algeria)" : "ערבית (אלג׳יריה)",
    "Arabic (Bahrain)" : "ערבית (בחריין)",
    "Arabic (Egypt)" : "ערבית (מצרים)",
    "Arabic (Iraq)" : "ערבית (עיראק)",
    "Arabic (Jordan)" : "ערבית (ירדן)",
    "Arabic (Kuwait)" : "ערבית (כוויית)",
    "Arabic (Lebanon)" : "ערבית (לבנון)",
    "Arabic (Libya)" : "ערבית (לוב)",
    "Arabic (Morocco)" : "ערבית (מרוקו)",
    "Arabic (Oman)" : "ערבית (עומאן)",
    "Arabic (Qatar)" : "ערבית (קטאר)",
    "Arabic (Saudi Arabia)" : "ערבית (ערב הסעודית)",
    "Arabic (Sudan)" : "ערבית (סודאן)",
    "Arabic (Syria)" : "ערבית (סוריה)",
    "Arabic (Tunisia)" : "ערבית (תוניסיה)",
    "Arabic (United Arab Emirates)" : "ערבית (איחוד האמירויות הערביות)",
    "Arabic (Yemen)" : "ערבית (תימן)",
    "Arabic" : "ערבית",
    "Armenian (Armenia)" : "ארמנית (ארמניה)",
    "Armenian" : "ארמנית",
    "Assamese (India)" : "אסאמית (הודו)",
    "Assamese" : "אסאמית",
    "Azerbaijani (Cyrillic)" : "אזרית (בכתב קירילי)",
    "Azerbaijani (Cyrillic, Azerbaijan)" : "אזרית (בכתב קירילי, אזרבייג׳ן)",
    "Azerbaijani (Latin)" : "אזרית (בכתב לטיני)",
    "Azerbaijani (Latin, Azerbaijan)" : "אזרית (בכתב לטיני, אזרבייג׳ן)",
    "Azerbaijani" : "אזרית",
    "Basque (Spain)" : "בסקית (ספרד)",
    "Basque" : "בסקית",
    "Belarusian (Belarus)" : "בלרוסית (בלרוס)",
    "Belarusian" : "בלרוסית",
    "Bengali (Bangladesh)" : "בנגלית (בנגלדש)",
    "Bengali (India)" : "בנגלית (הודו)",
    "Bengali" : "בנגלית",
    "Bosnian (Bosnia and Herzegovina)" : "בוסנית (בוסניה והרצגובינה)",
    "Bosnian" : "בוסנית",
    "Bulgarian (Bulgaria)" : "בולגרית (בולגריה)",
    "Bulgarian" : "בולגרית",
    "Burmese (Myanmar [Burma])" : "בורמזית (מיאנמר [בורמה])",
    "Burmese" : "בורמזית",
    "Catalan (Spain)" : "קטלאנית (ספרד)",
    "Catalan" : "קטלאנית",
    "Chiga (Uganda)" : "צ׳יגה (אוגנדה)",
    "Chiga" : "צ׳יגה",
    "Chinese" : "סינית",
    "Croatian (Croatia)" : "קרואטית (קרואטיה)",
    "Croatian" : "קרואטית",
    "Czech (Czech Republic)" : "צ׳כית (הרפובליקה הצ׳כית)",
    "Czech" : "צ׳כית",
    "Danish (Denmark)" : "דנית (דנמרק)",
    "Danish" : "דנית",
    "Dutch (Belgium)" : "הולנדית (בלגיה)",
    "Dutch (Netherlands)" : "הולנדית (הולנד)",
    "Dutch" : "הולנדית",
    "English (American Samoa)" : "אנגלית (סמואה האמריקנית)",
    "English (Australia)" : "אנגלית (אוסטרליה)",
    "English (Belgium)" : "אנגלית (בלגיה)",
    "English (Belize)" : "אנגלית (בליז)",
    "English (Botswana)" : "אנגלית (בוטסואנה)",
    "English (Canada)" : "אנגלית (קנדה)",
    "English (Guam)" : "אנגלית (גואם)",
    "English (India)" : "אנגלית (הודו)",
    "English (Ireland)" : "אנגלית (אירלנד)",
    "English (Jamaica)" : "אנגלית (ג׳מייקה)",
    "English (Malta)" : "אנגלית (מלטה)",
    "English (Marshall Islands)" : "אנגלית (איי מרשל)",
    "English (Mauritius)" : "אנגלית (מאוריציוס)",
    "English (Namibia)" : "אנגלית (נמיביה)",
    "English (New Zealand)" : "אנגלית (ניו זילנד)",
    "English (Northern Mariana Islands)" : "אנגלית (איי מריאנה הצפוניים)",
    "English (Pakistan)" : "אנגלית (פקיסטן)",
    "English (Philippines)" : "אנגלית (פיליפינים)",
    "English (Singapore)" : "אנגלית (סינגפור)",
    "English (South Africa)" : "אנגלית (דרום אפריקה)",
    "English (Trinidad and Tobago)" : "אנגליה (טרינידד וטובגו)",
    "English (United States)" : "אנגלית (ארצות הברית)",
    "English" : "אנגלית",
    "Esperanto" : "אספרנטו",
    "Estonian (Estonia)" : "אסטונית (אסטוניה)",
    "Estonian" : "אסטונית",
    "Filipino (Philippines)" : "פיליפינו (הפיליפינים)",
    "Filipino" : "פיליפינו",
    "Finnish (Finland)" : "פינית (פינלנד)",
    "Finnish" : "פינית",
    "French (Belgium)" : "צרפתית (בלגיה)",
    "French (Benin)" : "צרפתית (בנין)",
    "French (Burkina Faso)" : "צרפתית (בורקינה פאסו)",
    "French (Burundi)" : "צרפת (בורונדי)",
    "French (Cameroon)" : "צרפתית (קמרון)",
    "French (Canada)" : "צרפתית (קנדה)",
    "French (Central African Republic)" : "צרפתית (הרפובליקה המרכז אפריקאית)",
    "French (Chad)" : "צרפתית (צ׳אד)",
    "French (Comoros)" : "צרפתית (קומורוס)",
    "French (France)" : "צרפתית (צרפת)",
    "French (Monaco)" : "צרפתית (מונקו)",
    "French (Senegal)" : "צרפתית (סנגל)",
    "French (Switzerland)" : "צרפתית (שווייץ)",
    "French (Togo)" : "צרפתית (טוגו)",
    "French" : "צרפתית",
    "Fulah (Senegal)" : "פולה (סנגל)",
    "Fulah" : "פולה",
    "Galician (Spain)" : "גליסית (ספרד)",
    "Galician" : "גליסית",
    "Ganda (Uganda)" : "גנדה (אוגנדה)",
    "Ganda" : "גנדה",
    "Georgian (Georgia)" : "גאורגית (גאורגיה)",
    "Georgian" : "גאורגית",
    "German (Austria)" : "גרמנית (אוסטריה)",
    "German (Belgium)" : "גרמנית (בלגיה)",
    "German (Germany)" : "גרמנית (גרמניה)",
    "German (Liechtenstein)" : "גרמנית (ליכטנשטיין)",
    "German (Luxembourg)" : "גרמנית (לוקסמבורג)",
    "German (Switzerland)" : "גרמנית (שווייץ)",
    "German" : "גרמנית",
    "Greek (Cyprus)" : "יוונית (קפריסין)",
    "Greek (Greece)" : "יוונית (יוון)",
    "Greek" : "יוונית",
    "Hebrew (Israel)" : "עברית (ישראל)",
    "Hebrew" : "עברית",
    "Hungarian (Hungary)" : "הונגרית (הונגריה)",
    "Hungarian" : "הונגרית",
    "Icelandic (Iceland)" : "איסלנדית (איסלנד)",
    "Icelandic" : "איסלנד",
    "Indonesian (Indonesia)" : "אינדונזית (אינדונזיה)",
    "Indonesian" : "אינדונזית",
    "Irish (Ireland)" : "אירית (אירלנד)",
    "Irish" : "אירית",
    "Italian (Italy)" : "איטלקית (איטליה)",
    "Italian (Switzerland)" : "איטלקית (שווייץ)",
    "Italian" : "איטלקית",
    "Japanese (Japan)" : "יפנית (יפן)",
    "Japanese" : "יפנית",
    "Kalaallisut (Greenland)" : "כלשית (גרינלנד)",
    "Kalaallisut" : "כלשית",
    "Kalenjin (Kenya)" : "קלנג׳ין (קניה)",
    "Kalenjin" : "קלנג׳ין",
    "Kazakh (Cyrillic)" : "קזחית (קירילית)",
    "Kazakh (Cyrillic, Kazakhstan)" : "קזחית (קירילית, קזחסטן)",
    "Kazakh" : "קזחית",
    "Store credentials" : "שמירת אישורים",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over HTTP." : "cron.php רשום בשירות webcron לקרוא ל- cron.php בכל 15 דקות באמצעות HTTP.",
    "Use system cron service to call the cron.php file every 15 minutes." : "ניתן להשתמש בשירות cron של המערכת כדי לקרוא לקובץ cron.php בכל 15 דקות.",
    "Follow us on Google+" : "לעקוב אחרינו ב־Google+‎"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
